@@ -1,5 +1,5 @@
 
-#line 1 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 1 "ragel/i18n/ja.c.rl"
 #include <assert.h>
 #include <ruby.h>
 
@@ -80,7 +80,7 @@ static VALUE rb_eGherkinLexingError;
       lexer->line_number)
 
 
-#line 254 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 254 "ragel/i18n/ja.c.rl"
 
 
 /** Data **/
@@ -1131,13 +1131,13 @@ static const int lexer_error = 0;
 static const int lexer_en_main = 1;
 
 
-#line 258 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 258 "ragel/i18n/ja.c.rl"
 
 static VALUE 
 unindent(VALUE con, int start_col)
 {
   VALUE re;
-  // Gherkin will crash gracefully if the string representation of start_col pushes the pattern past 32 characters
+  /* Gherkin will crash gracefully if the string representation of start_col pushes the pattern past 32 characters */
   char pat[32]; 
   snprintf(pat, 32, "^[\t ]{0,%d}", start_col); 
   re = rb_reg_regcomp(rb_str_new2(pat));
@@ -1304,7 +1304,7 @@ static VALUE CLexer_scan(VALUE self, VALUE input)
 	cs = lexer_start;
 	}
 
-#line 425 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 425 "ragel/i18n/ja.c.rl"
     
 #line 1310 "ext/gherkin_lexer_ja/gherkin_lexer_ja.c"
 	{
@@ -1337,7 +1337,7 @@ _resume:
 			else if ( (*p) > *_mid )
 				_lower = _mid + 1;
 			else {
-				_trans += (_mid - _keys);
+				_trans += (unsigned int)(_mid - _keys);
 				goto _match;
 			}
 		}
@@ -1360,7 +1360,7 @@ _resume:
 			else if ( (*p) > _mid[1] )
 				_lower = _mid + 2;
 			else {
-				_trans += ((_mid - _keys)>>1);
+				_trans += (unsigned int)((_mid - _keys)>>1);
 				goto _match;
 			}
 		}
@@ -1380,7 +1380,7 @@ _match:
 		switch ( *_acts++ )
 		{
 	case 0:
-#line 83 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 83 "ragel/i18n/ja.c.rl"
 	{
 		MARK(content_start, p);
     lexer->current_line = lexer->line_number;
@@ -1388,20 +1388,20 @@ _match:
   }
 	break;
 	case 1:
-#line 89 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 89 "ragel/i18n/ja.c.rl"
 	{
     MARK(content_start, p);
   }
 	break;
 	case 2:
-#line 93 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 93 "ragel/i18n/ja.c.rl"
 	{
     lexer->current_line = lexer->line_number;
     lexer->start_col = p - data - lexer->last_newline;
   }
 	break;
 	case 3:
-#line 98 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 98 "ragel/i18n/ja.c.rl"
 	{
     int len = LEN(content_start, PTR_TO(final_newline));
     int type_len = LEN(docstring_content_type_start, PTR_TO(docstring_content_type_end));
@@ -1413,49 +1413,49 @@ _match:
   }
 	break;
 	case 4:
-#line 108 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 108 "ragel/i18n/ja.c.rl"
 	{ 
     MARK(docstring_content_type_start, p);
   }
 	break;
 	case 5:
-#line 112 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 112 "ragel/i18n/ja.c.rl"
 	{ 
     MARK(docstring_content_type_end, p);
   }
 	break;
 	case 6:
-#line 116 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 116 "ragel/i18n/ja.c.rl"
 	{
     STORE_KW_END_CON(feature);
   }
 	break;
 	case 7:
-#line 120 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 120 "ragel/i18n/ja.c.rl"
 	{
     STORE_KW_END_CON(background);
   }
 	break;
 	case 8:
-#line 124 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 124 "ragel/i18n/ja.c.rl"
 	{
     STORE_KW_END_CON(scenario);
   }
 	break;
 	case 9:
-#line 128 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 128 "ragel/i18n/ja.c.rl"
 	{
     STORE_KW_END_CON(scenario_outline);
   }
 	break;
 	case 10:
-#line 132 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 132 "ragel/i18n/ja.c.rl"
 	{
     STORE_KW_END_CON(examples);
   }
 	break;
 	case 11:
-#line 136 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 136 "ragel/i18n/ja.c.rl"
 	{
     store_kw_con(listener, "step",
       PTR_TO(keyword_start), LEN(keyword_start, PTR_TO(keyword_end)),
@@ -1464,34 +1464,34 @@ _match:
   }
 	break;
 	case 12:
-#line 143 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 143 "ragel/i18n/ja.c.rl"
 	{
     STORE_ATTR(comment);
     lexer->mark = 0;
   }
 	break;
 	case 13:
-#line 148 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 148 "ragel/i18n/ja.c.rl"
 	{
     STORE_ATTR(tag);
     lexer->mark = 0;
   }
 	break;
 	case 14:
-#line 153 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 153 "ragel/i18n/ja.c.rl"
 	{
     lexer->line_number += 1;
     MARK(final_newline, p);
   }
 	break;
 	case 15:
-#line 158 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 158 "ragel/i18n/ja.c.rl"
 	{
     MARK(last_newline, p + 1);
   }
 	break;
 	case 16:
-#line 162 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 162 "ragel/i18n/ja.c.rl"
 	{
     if (lexer->mark == 0) {
       MARK(mark, p);
@@ -1499,7 +1499,7 @@ _match:
   }
 	break;
 	case 17:
-#line 168 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 168 "ragel/i18n/ja.c.rl"
 	{
     MARK(keyword_end, p);
     MARK(keyword_start, PTR_TO(mark));
@@ -1508,13 +1508,13 @@ _match:
   }
 	break;
 	case 18:
-#line 175 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 175 "ragel/i18n/ja.c.rl"
 	{
     MARK(content_end, p);
   }
 	break;
 	case 19:
-#line 179 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 179 "ragel/i18n/ja.c.rl"
 	{
     p = p - 1;
     lexer->current_line = lexer->line_number;
@@ -1522,13 +1522,13 @@ _match:
   }
 	break;
 	case 20:
-#line 185 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 185 "ragel/i18n/ja.c.rl"
 	{
 		MARK(content_start, p);
   }
 	break;
 	case 21:
-#line 189 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 189 "ragel/i18n/ja.c.rl"
 	{
     VALUE re_pipe, re_newline, re_backslash;
     VALUE con = ENCODED_STR_NEW(PTR_TO(content_start), LEN(content_start, p));
@@ -1544,13 +1544,13 @@ _match:
   }
 	break;
 	case 22:
-#line 203 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 203 "ragel/i18n/ja.c.rl"
 	{
     rb_funcall(listener, rb_intern("row"), 2, current_row, INT2FIX(lexer->current_line));
   }
 	break;
 	case 23:
-#line 207 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 207 "ragel/i18n/ja.c.rl"
 	{
     int line;
     if (cs < lexer_first_final) {
@@ -1568,14 +1568,14 @@ _match:
         buff = data;
       }
 
-      // Allocate as a ruby string so that it gets cleaned up by GC
+      /* Allocate as a ruby string so that it gets cleaned up by GC */
       newstr_val = rb_str_new(buff, len);
       newstr = RSTRING_PTR(newstr_val);
 
 
       for (count = 0; count < len; count++) {
         if(buff[count] == 10) {
-          newstr[newstr_count] = '\0'; // terminate new string at first newline found
+          newstr[newstr_count] = '\0'; /* terminate new string at first newline found */
           break;
         } else {
           if (buff[count] == '%') {
@@ -1589,7 +1589,7 @@ _match:
       }
 
       line = lexer->line_number;
-      lexer_init(lexer); // Re-initialize so we can scan again with the same lexer
+      lexer_init(lexer); /* Re-initialize so we can scan again with the same lexer */
       raise_lexer_error(newstr, line);
     } else {
       rb_funcall(listener, rb_intern("eof"), 0);
@@ -1613,7 +1613,7 @@ _again:
 	while ( __nacts-- > 0 ) {
 		switch ( *__acts++ ) {
 	case 23:
-#line 207 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 207 "ragel/i18n/ja.c.rl"
 	{
     int line;
     if (cs < lexer_first_final) {
@@ -1631,14 +1631,14 @@ _again:
         buff = data;
       }
 
-      // Allocate as a ruby string so that it gets cleaned up by GC
+      /* Allocate as a ruby string so that it gets cleaned up by GC */
       newstr_val = rb_str_new(buff, len);
       newstr = RSTRING_PTR(newstr_val);
 
 
       for (count = 0; count < len; count++) {
         if(buff[count] == 10) {
-          newstr[newstr_count] = '\0'; // terminate new string at first newline found
+          newstr[newstr_count] = '\0'; /* terminate new string at first newline found */
           break;
         } else {
           if (buff[count] == '%') {
@@ -1652,7 +1652,7 @@ _again:
       }
 
       line = lexer->line_number;
-      lexer_init(lexer); // Re-initialize so we can scan again with the same lexer
+      lexer_init(lexer); /* Re-initialize so we can scan again with the same lexer */
       raise_lexer_error(newstr, line);
     } else {
       rb_funcall(listener, rb_intern("eof"), 0);
@@ -1667,13 +1667,13 @@ _again:
 	_out: {}
 	}
 
-#line 426 "/Users/ahellesoy/github/gherkin/tasks/../ragel/i18n/ja.c.rl"
+#line 426 "ragel/i18n/ja.c.rl"
 
     assert(p <= pe && "data overflow after parsing execute");
     assert(lexer->content_start <= len && "content starts after data end");
     assert(lexer->mark < len && "mark is after data end");
     
-    // Reset lexer by re-initializing the whole thing
+    /* Reset lexer by re-initializing the whole thing */
     lexer_init(lexer);
 
     if (cs == lexer_error) {
