@@ -6,9 +6,13 @@ module Gherkin
         
         text_start = 0
         arguments.each do |arg|
-          io.write(text_format.text(unpacked_step_name[text_start..arg.offset-1].pack("U*"))) unless arg.offset == 0
-          io.write(arg_format.text(arg.val))
-          text_start = arg.offset + arg.val.unpack("U*").length
+          if(arg.offset != 0 && !arg.offset.nil?)
+            io.write(text_format.text(unpacked_step_name[text_start..arg.offset-1].pack("U*")))
+          end
+          if(!arg.val.nil?)
+            io.write(arg_format.text(arg.val))
+            text_start = arg.offset + arg.val.unpack("U*").length
+          end
         end
         io.write(text_format.text(unpacked_step_name[text_start..-1].pack("U*"))) unless text_start == unpacked_step_name.length
       end
