@@ -1,6 +1,6 @@
-require 'yaml'
 require 'gherkin/rubify'
 require 'gherkin/native'
+require 'multi_json'
 
 module Gherkin
   class I18n
@@ -11,7 +11,7 @@ module Gherkin
     FEATURE_ELEMENT_KEYS = %w{feature background scenario scenario_outline examples}
     STEP_KEYWORD_KEYS    = %w{given when then and but}
     KEYWORD_KEYS         = FEATURE_ELEMENT_KEYS + STEP_KEYWORD_KEYS
-    LANGUAGES            = YAML.load_file(File.dirname(__FILE__) + '/i18n.yml')
+    LANGUAGES            = MultiJson.load(File.open(File.dirname(__FILE__) + '/i18n.json', 'r:utf-8').read)
 
     class << self
       include Rubify
@@ -30,7 +30,7 @@ module Gherkin
       # there is typically a code generation tool to generate regular expressions for recognising the
       # various I18n translations of Gherkin's keywords.
       #
-      # The +keywords+ arguments can be one of <tt>:feature</tt>, <tt>:background</tt>, <tt>:scenario</tt>, 
+      # The +keywords+ arguments can be one of <tt>:feature</tt>, <tt>:background</tt>, <tt>:scenario</tt>,
       # <tt>:scenario_outline</tt>, <tt>:examples</tt>, <tt>:step</tt>.
       def keyword_regexp(*keywords)
         unique_keywords = all.map do |i18n|
@@ -42,7 +42,7 @@ module Gherkin
             end
           end
         end
-        
+
         unique_keywords.flatten.compact.map{|kw| kw.to_s}.sort.reverse.uniq.join('|').gsub(/\*/, '\*')
       end
 
@@ -94,7 +94,7 @@ module Gherkin
     end
 
     def lexer(listener, force_ruby=false)
-      if force_ruby
+      if force_ruby || ENV['GHERKIN_RUBY'] =~ /true/i
         rb(listener)
       else
         begin
@@ -105,7 +105,7 @@ module Gherkin
         end
       end
     rescue LoadError => e
-      raise LexerNotFound, "No lexer was found for #{iso_code} (#{e.message}). Supported languages are listed in gherkin/i18n.yml."
+      raise LexerNotFound, "No lexer was found for #{iso_code} (#{e.message}). Supported languages are listed in gherkin/i18n.json."
     end
 
     def c(listener)
@@ -114,13 +114,8 @@ module Gherkin
     end
 
     def rb(listener)
-      require 'gherkin/rb_lexer'
-      RbLexer[underscored_iso_code].new(listener)
-    end
-
-    def js(listener)
-      require 'gherkin/js_lexer'
-      JsLexer[underscored_iso_code].new(listener)
+      require "gherkin/lexer/#{underscored_iso_code}"
+      Lexer.const_get(underscored_iso_code.capitalize).new(listener)
     end
 
     def underscored_iso_code
@@ -136,6 +131,7 @@ module Gherkin
     def code_keywords
       result = step_keywords.map{|keyword| self.class.code_keyword_for(keyword)}
       result.delete('*')
+      result.delete_if {|kw| kw =~ /^\d/}
       result
     end
 
@@ -155,14 +151,14 @@ module Gherkin
       gherkin_keyword_table = KEYWORD_KEYS.map do |key|
         Formatter::Model::Row.new([], [key, keywords(key).map{|keyword| %{"#{keyword}"}}.join(', ')], nil)
       end
-      
+
       code_keyword_table = STEP_KEYWORD_KEYS.map do |key|
         code_keywords = keywords(key).reject{|keyword| keyword == '* '}.map do |keyword|
           %{"#{self.class.code_keyword_for(keyword)}"}
         end.join(', ')
         Formatter::Model::Row.new([], ["#{key} (code)", code_keywords], nil)
       end
-      
+
       pf.table(gherkin_keyword_table + code_keyword_table)
       io.string
     end
