@@ -1,3 +1,4 @@
+#encoding: utf-8
 require 'gherkin/i18n'
 require 'gherkin/native'
 
@@ -9,13 +10,14 @@ module Gherkin
     class I18nLexer
       native_impl('gherkin')
 
-      COMMENT_OR_EMPTY_LINE_PATTERN = /^\s*#|^\s*$/
-      LANGUAGE_PATTERN = /^\s*#\s*language\s*:\s*([a-zA-Z\-]+)/ #:nodoc:
+      COMMENT_OR_EMPTY_LINE_PATTERN = /^(\xEF\xBB\xBF)?\s*#|^\s*$/
+      LANGUAGE_PATTERN = /^(\xEF\xBB\xBF)?\s*#\s*language\s*:\s*([a-zA-Z\-]+)/ #:nodoc:
       attr_reader :i18n_language
 
-      def initialize(listener, force_ruby=false)
+      def initialize(listener, force_ruby=false, iso_code='en')
         @listener = listener
         @force_ruby = force_ruby
+        @iso_code = iso_code
       end
 
       def scan(source)
@@ -30,11 +32,11 @@ module Gherkin
       end
 
       def lang(source)
-        key = 'en'
+        key = @iso_code
         source.each_line do |line|
           break unless COMMENT_OR_EMPTY_LINE_PATTERN =~ line
           if LANGUAGE_PATTERN =~ line
-            key = $1
+            key = $2
             break
           end
         end
