@@ -5,7 +5,9 @@ class Class
     class << self
       def new(*args)
         js = {
-          'Gherkin::Formatter::JSONFormatter' => 'js/lib/gherkin/formatter/json_formatter.js'
+          # Add more mappings here if needed. The mappings are only used by test code.
+          'Gherkin::Formatter::JSONFormatter' => 'js/lib/gherkin/formatter/json_formatter.js',
+          'Gherkin::Lexer::En' => 'js/lib/gherkin/lexer/en.js'
         }[self.name]
         if(js)
           Proxy.new(js, *args)
@@ -24,7 +26,7 @@ class Class
       # Mimic Node.js / Firebug console.log
       cxt['console'] = STDOUT
       def STDOUT.log(*a)
-        puts sprintf(*a)
+        puts sprintf(*a.map(&:to_s))
       end
 
       cxt.load(js)
